﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Summary.Model;
using Stimulsoft.Report;

namespace Summary
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            Loaded += MainWindowLoaded;
        }

        private List<VatRate> vatRates;
        private List<Document> reportData;
        private void PrepareVatRates()
        {
            vatRates = new List<VatRate>(6);
            vatRates.Add(new VatRate("23", 23));
            vatRates.Add(new VatRate("8", 8));
            vatRates.Add(new VatRate("5", 5));
            vatRates.Add(new VatRate("0", 0));
            vatRates.Add(new VatRate("zw", 0));
            vatRates.Add(new VatRate("nieop.", 0));
        }
        private List<RateItem> PrepareRateItems()
        {
            var rateItems = new List<RateItem>(6);
            foreach (var vat in vatRates)
            {
                rateItems.Add(new RateItem { VatRate = vat });
            }
            return rateItems;
        }
        private List<Document> PrepareData()
        {
            PrepareVatRates();
            var documents = new List<Document>(17);

            #region 1
            var doc = new Document
            {
                AccountingDocument = "",
                PurchaseValue = 0,
                SalesValue = 0,
                TIN = "865-256-66-42",
                TotalGross = 0,
                TotalNet = 0,
                TotalVat = 0,
            };
            doc.RateItems = PrepareRateItems();
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Więzienna 85 , 66-666 Kraków",
                ContractorName = "AD KOBRA",
                ContractorTIN = "865-256-66-42",
                Description = string.Concat(Enumerable.Repeat("opis ", 20)),
                DocumentNumber = "ręczny",
                IssueDate = new DateTime(2014, 1, 1),
                SaleDate = new DateTime(2014, 1, 1)
            };
            documents.Add(doc);
            #endregion

            #region 2
            doc = new Document
            {
                AccountingDocument = "1",
                PurchaseValue = 0,
                SalesValue = 0,
                TIN = "2",
                TotalGross = 0,
                TotalNet = 0,
                TotalVat = 0
            };
            doc.RateItems = PrepareRateItems();
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Polanka 12/6 , 54-365 Wrocław",
                ContractorName = "ABC s.c.",
                ContractorTIN = "2",
                Description = "do FVAT: FM 1/CENTRALA/2013",
                DocumentNumber = "KFVAT: KFM 1/CENTRALA/2014",
                IssueDate = new DateTime(2014, 1, 9),
                SaleDate = new DateTime(2014, 1, 9)
            };
            documents.Add(doc);
            #endregion

            #region 3
            doc = new Document
            {
                AccountingDocument = "2",
                PurchaseValue = 179.86m,
                SalesValue = 518.63m,
                TIN = "2",
                TotalGross = 338.77m,
                TotalNet = 275.97m,
                TotalVat = 62.8m
            };
            doc.RateItems = PrepareRateItems();
            doc.RateItems[0].Net = 273m;
            doc.RateItems[0].Vat = 62.8m;
            doc.RateItems[0].Gross = doc.RateItems[0].Net + doc.RateItems[0].Vat;
            doc.RateItems[4].Net = 2.97m;
            doc.RateItems[4].Gross = 2.97m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Polanka 12/6 , 54-365 Wrocław",
                ContractorName = "ABC s.c.",
                ContractorTIN = "2",
                Description = "FZ 6/CENTRALA/2014, RR 2/CENTRALA/2014",
                DocumentNumber = "FVAT: FM 1/CENTRALA/2014",
                IssueDate = new DateTime(2014, 5, 13),
                SaleDate = new DateTime(2014, 5, 13)
            };
            documents.Add(doc);
            #endregion

            #region 4
            doc = new Document
            {
                AccountingDocument = "3",
                PurchaseValue = -10.56m,
                SalesValue = -10.55m,
                TIN = "2",
                TotalGross = 0.01m,
                TotalNet = 0.01m,
                TotalVat = 0
            };
            doc.RateItems = PrepareRateItems();
            doc.RateItems[4].Net = 0.01m;
            doc.RateItems[4].Gross = 0.01m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Polanka 12/6 , 54-365 Wrocław",
                ContractorName = "ABC s.c.",
                ContractorTIN = "2",
                Description = "do FVAT: FM 1/CENTRALA/2014",
                DocumentNumber = "KFVAT: KFM 2/CENTRALA/2014",
                IssueDate = new DateTime(2014, 5, 13),
                SaleDate = new DateTime(2014, 5, 13)
            };
            documents.Add(doc);
            #endregion

            #region 5
            doc = new Document
            {
                AccountingDocument = "4",
                PurchaseValue = 20.89m,
                SalesValue = 104.83m,
                TIN = "3333333333",
                TotalGross = 83.94m,
                TotalNet = 83.94m,
                TotalVat = 0
            };
            doc.RateItems = PrepareRateItems();
            doc.RateItems[4].Net = 83.94m;
            doc.RateItems[4].Gross = 83.94m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Pl. Orląt Lwowskich 1, 53-605 Wrocław",
                ContractorName = "Ins Bank",
                ContractorTIN = "3333333333",
                Description = "do FVAT",
                DocumentNumber = "KFVAT: KFM 3/CENTRALA/2014",
                IssueDate = new DateTime(2014, 5, 13),
                SaleDate = new DateTime(2014, 5, 13)
            };
            documents.Add(doc);
            #endregion

            #region 6
            doc = new Document
            {
                AccountingDocument = "5",
                PurchaseValue = 20.89m,
                SalesValue = 104.83m,
                TIN = "3333333333",
                TotalGross = 83.94m,
                TotalNet = 83.94m,
                TotalVat = 0
            };
            doc.RateItems = PrepareRateItems();
            doc.RateItems[4].Net = 83.94m;
            doc.RateItems[4].Gross = 83.94m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Pl. Orląt Lwowskich 1, 53-605 Wrocław",
                ContractorName = "Ins Bank",
                ContractorTIN = "3333333333",
                Description = "do FVAT",
                DocumentNumber = "KFVAT: KFM 4/CENTRALA/2014",
                IssueDate = new DateTime(2014, 5, 13),
                SaleDate = new DateTime(2014, 5, 13)
            };
            documents.Add(doc);
            #endregion

            #region 7
            doc = new Document
            {
                AccountingDocument = "6",
                PurchaseValue = 20.9m,
                SalesValue = 104.84m,
                TIN = "3333333333",
                TotalGross = 83.95m,
                TotalNet = 83.95m,
                TotalVat = 0
            };
            doc.RateItems = PrepareRateItems();
            doc.RateItems[4].Net = 83.95m;
            doc.RateItems[4].Gross = 83.95m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Pl. Orląt Lwowskich 1, 53-605 Wrocław",
                ContractorName = "Ins Bank",
                ContractorTIN = "3333333333",
                Description = "do FVAT",
                DocumentNumber = "KFVAT: KFM 5/CENTRALA/2014",
                IssueDate = new DateTime(2014, 5, 13),
                SaleDate = new DateTime(2014, 5, 13)
            };
            documents.Add(doc);
            #endregion

            #region 8
            doc = new Document
            {
                AccountingDocument = "7",
                PurchaseValue = 20.9m,
                SalesValue = 104.83m,
                TIN = "3333333333",
                TotalGross = 83.93m,
                TotalNet = 83.93m,
                TotalVat = 0
            };
            doc.RateItems = PrepareRateItems();
            doc.RateItems[4].Net = 83.93m;
            doc.RateItems[4].Gross = 83.93m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Pl. Orląt Lwowskich 1, 53-605 Wrocław",
                ContractorName = "Ins Bank",
                ContractorTIN = "3333333333",
                Description = "do FVAT",
                DocumentNumber = "KFVAT: KFM 6/CENTRALA/2014",
                IssueDate = new DateTime(2014, 5, 13),
                SaleDate = new DateTime(2014, 5, 13)
            };
            documents.Add(doc);
            #endregion

            #region 9
            doc = new Document
            {
                AccountingDocument = "8",
                PurchaseValue = 20.9m,
                SalesValue = 104.83m,
                TIN = "3333333333",
                TotalGross = 83.93m,
                TotalNet = 83.93m,
                TotalVat = 0
            };
            doc.RateItems = PrepareRateItems();
            doc.RateItems[4].Net = 83.93m;
            doc.RateItems[4].Gross = 83.93m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Pl. Orląt Lwowskich 1, 53-605 Wrocław",
                ContractorName = "Ins Bank",
                ContractorTIN = "3333333333",
                Description = "FZ 14/CENTRALA/2014 do FVAT",
                DocumentNumber = "KFVAT: KFM 7/CENTRALA/2014",
                IssueDate = new DateTime(2014, 5, 13),
                SaleDate = new DateTime(2014, 5, 13)
            };
            documents.Add(doc);
            #endregion

            #region 10
            doc = new Document
            {
                AccountingDocument = "9",
                PurchaseValue = 22m,
                SalesValue = 170m,
                TIN = "2",
                TotalGross = 148m,
                TotalNet = 148m,
                TotalVat = 0
            };
            doc.RateItems = PrepareRateItems();
            doc.RateItems[4].Net = 144m;
            doc.RateItems[4].Gross = 144m;
            doc.RateItems[5].Net = 4m;
            doc.RateItems[5].Gross = 4m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Polanka 12/6 , 54-365 Wrocław",
                ContractorName = "ABC s.c.",
                ContractorTIN = "2",
                Description = "",
                DocumentNumber = "FVAT: FM 2/CENTRALA/2014",
                IssueDate = new DateTime(2014, 5, 14),
                SaleDate = new DateTime(2014, 5, 14)
            };
            documents.Add(doc);
            #endregion

            #region 11
            doc = new Document
            {
                AccountingDocument = "",
                PurchaseValue = 0,
                SalesValue = 0,
                TIN = "865-256-66-42",
                TotalGross = 0,
                TotalNet = 0,
                TotalVat = 0
            };
            doc.RateItems = PrepareRateItems();
            doc.RateItems[0].Net = 273m;
            doc.RateItems[0].Vat = 62.8m;
            doc.RateItems[0].Gross = doc.RateItems[0].Net + doc.RateItems[0].Vat;
            doc.RateItems[4].Net = 2.97m;
            doc.RateItems[4].Gross = 2.97m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Polanka 12/6 , 54-365 Wrocław",
                ContractorName = "ABC s.c.",
                ContractorTIN = "2",
                Description = "FZ 6/CENTRALA/2014, RR 2/CENTRALA/2014",
                DocumentNumber = "34",
                IssueDate = new DateTime(2014, 12, 31),
                SaleDate = new DateTime(2014, 12, 31)
            };
            documents.Add(doc);
            #endregion

            #region 12
            doc = new Document
            {
                AccountingDocument = "",
                PurchaseValue = 179.86m,
                SalesValue = 518.63m,
                TIN = "2",
                TotalGross = 338.77m,
                TotalNet = 275.97m,
                TotalVat = 62.8m
            };
            doc.RateItems = PrepareRateItems();
            doc.RateItems[4].Net = 83.94m;
            doc.RateItems[4].Gross = 83.94m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Pl. Orląt Lwowskich 1, 53-605 Wrocław",
                ContractorName = "Ins Bank",
                ContractorTIN = "3333333333",
                Description = "do FVAT",
                DocumentNumber = "54",
                IssueDate = new DateTime(2014, 12, 31),
                SaleDate = new DateTime(2014, 12, 31)
            };
            documents.Add(doc);
            #endregion

            #region 13
            doc = new Document
            {
                AccountingDocument = "",
                PurchaseValue = 179.86m,
                SalesValue = 518.63m,
                TIN = "2",
                TotalGross = 338.77m,
                TotalNet = 275.97m,
                TotalVat = 62.8m
            };
            doc.RateItems = PrepareRateItems();
            doc.RateItems[0].Net = 273m;
            doc.RateItems[0].Vat = 62.8m;
            doc.RateItems[0].Gross = doc.RateItems[0].Net + doc.RateItems[0].Vat;
            doc.RateItems[4].Net = 2.97m;
            doc.RateItems[4].Gross = 2.97m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Polanka 12/6 , 54-365 Wrocław",
                ContractorName = "ABC s.c.",
                ContractorTIN = "2",
                Description = "FZ 6/CENTRALA/2014, RR 2/CENTRALA/2014",
                DocumentNumber = "111",
                IssueDate = new DateTime(2014, 12, 31),
                SaleDate = new DateTime(2014, 12, 31)
            };
            documents.Add(doc);
            #endregion

            #region 14
            doc = new Document
            {
                AccountingDocument = "",
                PurchaseValue = 179.86m,
                SalesValue = 518.63m,
                TIN = "2",
                TotalGross = 338.77m,
                TotalNet = 275.97m,
                TotalVat = 62.8m
            };
            doc.RateItems = PrepareRateItems();
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Więzienna 85 , 66-666 Kraków",
                ContractorName = "AD KOBRA",
                ContractorTIN = "865-256-66-42",
                Description = string.Concat(Enumerable.Repeat("opis ", 20)),
                DocumentNumber = "123",
                IssueDate = new DateTime(2014, 12, 31),
                SaleDate = new DateTime(2014, 12, 31)
            };
            documents.Add(doc);
            #endregion

            #region 15
            doc = new Document
            {
                AccountingDocument = "",
                PurchaseValue = 20.89m,
                SalesValue = 104.83m,
                TIN = "3333333333",
                TotalGross = 83.94m,
                TotalNet = 83.94m,
                TotalVat = 0
            };
            doc.RateItems = PrepareRateItems();
            doc.RateItems[4].Net = 83.94m;
            doc.RateItems[4].Gross = 83.94m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Pl. Orląt Lwowskich 1, 53-605 Wrocław",
                ContractorName = "Ins Bank",
                ContractorTIN = "3333333333",
                Description = "do FVAT",
                DocumentNumber = "127",
                IssueDate = new DateTime(2014, 12, 31),
                SaleDate = new DateTime(2014, 12, 31)
            };
            documents.Add(doc);
            #endregion

            #region 16
            doc = new Document
            {
                AccountingDocument = "",
                PurchaseValue = 20.89m,
                SalesValue = 104.83m,
                TIN = "3333333333",
                TotalGross = 83.94m,
                TotalNet = 83.94m,
                TotalVat = 0
            };
            doc.RateItems = PrepareRateItems();
            doc.RateItems[0].Net = 273m;
            doc.RateItems[0].Vat = 62.8m;
            doc.RateItems[0].Gross = doc.RateItems[0].Net + doc.RateItems[0].Vat;
            doc.RateItems[4].Net = 2.97m;
            doc.RateItems[4].Gross = 2.97m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Polanka 12/6 , 54-365 Wrocław",
                ContractorName = "ABC s.c.",
                ContractorTIN = "2",
                Description = "FZ 6/CENTRALA/2014, RR 2/CENTRALA/2014",
                DocumentNumber = "434",
                IssueDate = new DateTime(2014, 12, 31),
                SaleDate = new DateTime(2014, 12, 31)
            };
            documents.Add(doc);
            #endregion

            #region 17
            doc = new Document
            {
                AccountingDocument = "",
                PurchaseValue = 20.89m,
                SalesValue = 104.83m,
                TIN = "3333333333",
                TotalGross = 83.94m,
                TotalNet = 83.94m,
                TotalVat = 0
            };
            doc.RateItems = PrepareRateItems();
            documents.Add(doc);
            doc.RateItems[4].Net = 83.94m;
            doc.RateItems[4].Gross = 83.94m;
            doc.VatRecordsEntry = new VatRecordsEntry
            {
                ContractorAddress = "Pl. Orląt Lwowskich 1, 53-605 Wrocław",
                ContractorName = "Ins Bank",
                ContractorTIN = "3333333333",
                Description = "do FVAT",
                DocumentNumber = "123654",
                IssueDate = new DateTime(2014, 12, 31),
                SaleDate = new DateTime(2014, 12, 31)
            };
            #endregion

            return documents;
        }

        void MainWindowLoaded(object sender, RoutedEventArgs e)
        {
            reportData = PrepareData();
        }

        bool isPortrait = true;
        private void Portrait_Click(object sender, RoutedEventArgs e)
        {
            isPortrait = true;
        }

        private void Landscape_Click(object sender, RoutedEventArgs e)
        {
            isPortrait = false;
        }

        private void Generate_Click(object sender, RoutedEventArgs e)
        {
            var template = isPortrait ? "Portrait.mrt" : "Landscape.mrt";
            var report = new StiReport();
            report.Load(template);
            report.RegBusinessObject("Data", reportData);
            report.RegBusinessObject("VatRates", vatRates);
            report.ShowWithWpf();
        }
    }
}
